# flake8: noqa
test_cos_sim_request = {
    "vec_a": [
        0.4659823775291443,
        -0.3153218626976013,
        0.6579014658927917,
        0.25195541977882385,
        0.8999965786933899,
        -1.0714123249053955,
        -0.9786702394485474,
        0.6616522073745728,
        -0.31831589341163635,
        0.16379745304584503,
        1.2099021673202515,
        0.07213163375854492,
        -0.48916301131248474,
        -0.3587180972099304,
        0.7435992360115051,
        1.3542253971099854,
        0.38033729791641235,
        0.0649452954530716,
        0.9417875409126282,
        0.6023600697517395,
        0.6640006303787231,
        0.9831154942512512,
        0.4195910394191742,
        0.051800597459077835,
        1.1065667867660522,
        -0.8020269274711609,
        0.06637042760848999,
        0.18136915564537048,
        -0.9444266557693481,
        1.014452576637268,
        0.5683286786079407,
        -1.0539014339447021,
        -0.3495505452156067,
        0.3295270800590515,
        0.24656789004802704,
        0.14886564016342163,
        0.07124347984790802,
        -0.22941875457763672,
        0.0966271460056305,
        -0.624869704246521,
        -0.25067368149757385,
        0.38024526834487915,
        -0.18982505798339844,
        0.17489880323410034,
        0.35698676109313965,
        -1.53689706325531,
        0.5027157068252563,
        0.3197987675666809,
        -0.3344493508338928,
        -1.0100492238998413,
        -0.4307926595211029,
        0.06530480831861496,
        0.388069212436676,
        1.2258079051971436,
        0.2573576867580414,
        -1.4153484106063843,
        0.21512946486473083,
        -0.4719557762145996,
        -0.6846925020217896,
        0.7439391613006592,
        0.3577089011669159,
        -0.3426345884799957,
        -0.5827887058258057,
        -0.6950613260269165,
        -0.048700667917728424,
        -0.7913966774940491,
        0.14284658432006836,
        -0.3781901001930237,
        0.6843563914299011,
        0.7788859605789185,
        0.09959635138511658,
        -0.6300409436225891,
        0.15019404888153076,
        -1.0389961004257202,
        0.632123589515686,
        -0.06940846145153046,
        0.9757447242736816,
        -0.5996688008308411,
        -0.44081777334213257,
        -1.6316324472427368,
        -0.48350363969802856,
        -0.5468633770942688,
        0.07794250547885895,
        -0.0878940224647522,
        -0.10245438665151596,
        -0.6175057888031006,
        -0.6156563758850098,
        0.7791014909744263,
        1.2380365133285522,
        -0.34855180978775024,
        0.8996330499649048,
        -0.41394367814064026,
        0.22871065139770508,
        0.5231090188026428,
        0.22992947697639465,
        -0.5886858105659485,
        -1.082435965538025,
        -0.4711030125617981,
        0.5441762208938599,
        0.2527487874031067,
        0.283369243144989,
        -0.574310839176178,
        0.14843356609344482,
        -0.4268193244934082,
        -0.35167622566223145,
        0.9800344705581665,
        -0.07432089745998383,
        -0.6011855006217957,
        -0.22904041409492493,
        -0.1416512131690979,
        -0.36471518874168396,
        -0.9252616167068481,
        -0.2224564105272293,
        0.6450538635253906,
        -0.17642466723918915,
        -0.5521590709686279,
        -0.21906904876232147,
        0.09184394776821136,
        0.9728181958198547,
        0.8069297671318054,
        0.28630879521369934,
        0.9783782958984375,
        0.02980978414416313,
        -0.6455193758010864,
        -0.011217450723052025,
        -0.13945266604423523,
        -0.30015814304351807,
        -0.44322675466537476,
    ],
    "vec_b": [
        0.37329187989234924,
        -0.40346741676330566,
        0.8592567443847656,
        0.3341558575630188,
        1.2025468349456787,
        -1.1751782894134521,
        -0.8372662663459778,
        0.15748336911201477,
        0.23039093613624573,
        -0.2539535164833069,
        1.440635323524475,
        0.14066992700099945,
        -0.5031348466873169,
        -0.3861887454986572,
        0.7613312005996704,
        1.2471444606781006,
        0.11814567446708679,
        0.03536860644817352,
        1.1471662521362305,
        0.5752367973327637,
        0.7180403470993042,
        0.6445664167404175,
        0.36619728803634644,
        -0.07969420403242111,
        1.4961261749267578,
        -0.9455313682556152,
        -0.27364030480384827,
        -0.21270805597305298,
        -0.7905346751213074,
        0.8472232818603516,
        0.4580339193344116,
        -1.2355133295059204,
        -0.40746384859085083,
        0.7605623006820679,
        0.4294317960739136,
        -0.15292391180992126,
        0.15050935745239258,
        -0.6681801080703735,
        0.506782591342926,
        -1.114694356918335,
        -0.674319326877594,
        0.3930550217628479,
        0.2870106101036072,
        0.1258777678012848,
        0.5929133296012878,
        -1.4213206768035889,
        0.6026835441589355,
        -0.07108429074287415,
        -0.3067375421524048,
        -0.9284607768058777,
        -0.12709805369377136,
        0.27302825450897217,
        0.02887706086039543,
        0.7595998048782349,
        0.2929617762565613,
        -1.391342043876648,
        0.5138117671012878,
        -0.2694222927093506,
        -0.3943999409675598,
        0.15931561589241028,
        0.49289947748184204,
        0.003158755600452423,
        -0.5678439140319824,
        -0.9501131772994995,
        0.17512550950050354,
        -0.6065792441368103,
        -0.3563533425331116,
        -0.5618597269058228,
        0.584686279296875,
        0.6040061116218567,
        -0.41511911153793335,
        -0.2238534688949585,
        -0.13113263249397278,
        -1.1388676166534424,
        0.695239782333374,
        0.1289304494857788,
        0.8361332416534424,
        -0.6084146499633789,
        -0.6792680025100708,
        -1.8542686700820923,
        -0.7270863056182861,
        -0.49272865056991577,
        0.08106715232133865,
        -0.27974581718444824,
        0.28775274753570557,
        -0.5932867527008057,
        -0.8847337365150452,
        1.1054117679595947,
        0.8297420144081116,
        -0.49890798330307007,
        0.5436344146728516,
        -0.29017025232315063,
        0.010423809289932251,
        0.7277359962463379,
        0.9248435497283936,
        -0.23434202373027802,
        -0.8785954713821411,
        -0.12769189476966858,
        0.6882693767547607,
        0.17912714183330536,
        0.4859697222709656,
        -0.3216395974159241,
        -0.045606136322021484,
        -0.05983754247426987,
        -0.2508890926837921,
        1.1709513664245605,
        -0.38468217849731445,
        -0.7005789875984192,
        -0.07699798047542572,
        -0.046769075095653534,
        -0.1636989712715149,
        -1.3723564147949219,
        -0.09783443808555603,
        0.678470253944397,
        0.1777549386024475,
        -0.3029346764087677,
        -0.1616893708705902,
        0.4771544337272644,
        0.502882719039917,
        0.4454941153526306,
        0.313443660736084,
        1.3923258781433105,
        -0.07238419353961945,
        -0.3452478051185608,
        0.07697200030088425,
        -0.19424647092819214,
        -0.40326178073883057,
        -0.5231634974479675,
    ],
}

test_context_emb_request = {"contexts": ["Share my location with Hillary's sister"]}

test_context_emb_response = {
    "context_embed": [
        0.4659823775291443,
        -0.3153218626976013,
        0.6579014658927917,
        0.25195541977882385,
        0.8999965786933899,
        -1.0714123249053955,
        -0.9786702394485474,
        0.6616522073745728,
        -0.31831589341163635,
        0.16379745304584503,
        1.2099021673202515,
        0.07213163375854492,
        -0.48916301131248474,
        -0.3587180972099304,
        0.7435992360115051,
        1.3542253971099854,
        0.38033729791641235,
        0.0649452954530716,
        0.9417875409126282,
        0.6023600697517395,
        0.6640006303787231,
        0.9831154942512512,
        0.4195910394191742,
        0.051800597459077835,
        1.1065667867660522,
        -0.8020269274711609,
        0.06637042760848999,
        0.18136915564537048,
        -0.9444266557693481,
        1.014452576637268,
        0.5683286786079407,
        -1.0539014339447021,
        -0.3495505452156067,
        0.3295270800590515,
        0.24656789004802704,
        0.14886564016342163,
        0.07124347984790802,
        -0.22941875457763672,
        0.0966271460056305,
        -0.624869704246521,
        -0.25067368149757385,
        0.38024526834487915,
        -0.18982505798339844,
        0.17489880323410034,
        0.35698676109313965,
        -1.53689706325531,
        0.5027157068252563,
        0.3197987675666809,
        -0.3344493508338928,
        -1.0100492238998413,
        -0.4307926595211029,
        0.06530480831861496,
        0.388069212436676,
        1.2258079051971436,
        0.2573576867580414,
        -1.4153484106063843,
        0.21512946486473083,
        -0.4719557762145996,
        -0.6846925020217896,
        0.7439391613006592,
        0.3577089011669159,
        -0.3426345884799957,
        -0.5827887058258057,
        -0.6950613260269165,
        -0.048700667917728424,
        -0.7913966774940491,
        0.14284658432006836,
        -0.3781901001930237,
        0.6843563914299011,
        0.7788859605789185,
        0.09959635138511658,
        -0.6300409436225891,
        0.15019404888153076,
        -1.0389961004257202,
        0.632123589515686,
        -0.06940846145153046,
        0.9757447242736816,
        -0.5996688008308411,
        -0.44081777334213257,
        -1.6316324472427368,
        -0.48350363969802856,
        -0.5468633770942688,
        0.07794250547885895,
        -0.0878940224647522,
        -0.10245438665151596,
        -0.6175057888031006,
        -0.6156563758850098,
        0.7791014909744263,
        1.2380365133285522,
        -0.34855180978775024,
        0.8996330499649048,
        -0.41394367814064026,
        0.22871065139770508,
        0.5231090188026428,
        0.22992947697639465,
        -0.5886858105659485,
        -1.082435965538025,
        -0.4711030125617981,
        0.5441762208938599,
        0.2527487874031067,
        0.283369243144989,
        -0.574310839176178,
        0.14843356609344482,
        -0.4268193244934082,
        -0.35167622566223145,
        0.9800344705581665,
        -0.07432089745998383,
        -0.6011855006217957,
        -0.22904041409492493,
        -0.1416512131690979,
        -0.36471518874168396,
        -0.9252616167068481,
        -0.2224564105272293,
        0.6450538635253906,
        -0.17642466723918915,
        -0.5521590709686279,
        -0.21906904876232147,
        0.09184394776821136,
        0.9728181958198547,
        0.8069297671318054,
        0.28630879521369934,
        0.9783782958984375,
        0.02980978414416313,
        -0.6455193758010864,
        -0.011217450723052025,
        -0.13945266604423523,
        -0.30015814304351807,
        -0.44322675466537476,
    ]
}

test_candidate_emb_request = {"candidates": ["sharecurrentlocation"]}

test_candidate_emb_response = {
    "candidate_embed": [
        [
            0.37329187989234924,
            -0.40346741676330566,
            0.8592567443847656,
            0.3341558575630188,
            1.2025468349456787,
            -1.1751782894134521,
            -0.8372662663459778,
            0.15748336911201477,
            0.23039093613624573,
            -0.2539535164833069,
            1.440635323524475,
            0.14066992700099945,
            -0.5031348466873169,
            -0.3861887454986572,
            0.7613312005996704,
            1.2471444606781006,
            0.11814567446708679,
            0.03536860644817352,
            1.1471662521362305,
            0.5752367973327637,
            0.7180403470993042,
            0.6445664167404175,
            0.36619728803634644,
            -0.07969420403242111,
            1.4961261749267578,
            -0.9455313682556152,
            -0.27364030480384827,
            -0.21270805597305298,
            -0.7905346751213074,
            0.8472232818603516,
            0.4580339193344116,
            -1.2355133295059204,
            -0.40746384859085083,
            0.7605623006820679,
            0.4294317960739136,
            -0.15292391180992126,
            0.15050935745239258,
            -0.6681801080703735,
            0.506782591342926,
            -1.114694356918335,
            -0.674319326877594,
            0.3930550217628479,
            0.2870106101036072,
            0.1258777678012848,
            0.5929133296012878,
            -1.4213206768035889,
            0.6026835441589355,
            -0.07108429074287415,
            -0.3067375421524048,
            -0.9284607768058777,
            -0.12709805369377136,
            0.27302825450897217,
            0.02887706086039543,
            0.7595998048782349,
            0.2929617762565613,
            -1.391342043876648,
            0.5138117671012878,
            -0.2694222927093506,
            -0.3943999409675598,
            0.15931561589241028,
            0.49289947748184204,
            0.003158755600452423,
            -0.5678439140319824,
            -0.9501131772994995,
            0.17512550950050354,
            -0.6065792441368103,
            -0.3563533425331116,
            -0.5618597269058228,
            0.584686279296875,
            0.6040061116218567,
            -0.41511911153793335,
            -0.2238534688949585,
            -0.13113263249397278,
            -1.1388676166534424,
            0.695239782333374,
            0.1289304494857788,
            0.8361332416534424,
            -0.6084146499633789,
            -0.6792680025100708,
            -1.8542686700820923,
            -0.7270863056182861,
            -0.49272865056991577,
            0.08106715232133865,
            -0.27974581718444824,
            0.28775274753570557,
            -0.5932867527008057,
            -0.8847337365150452,
            1.1054117679595947,
            0.8297420144081116,
            -0.49890798330307007,
            0.5436344146728516,
            -0.29017025232315063,
            0.010423809289932251,
            0.7277359962463379,
            0.9248435497283936,
            -0.23434202373027802,
            -0.8785954713821411,
            -0.12769189476966858,
            0.6882693767547607,
            0.17912714183330536,
            0.4859697222709656,
            -0.3216395974159241,
            -0.045606136322021484,
            -0.05983754247426987,
            -0.2508890926837921,
            1.1709513664245605,
            -0.38468217849731445,
            -0.7005789875984192,
            -0.07699798047542572,
            -0.046769075095653534,
            -0.1636989712715149,
            -1.3723564147949219,
            -0.09783443808555603,
            0.678470253944397,
            0.1777549386024475,
            -0.3029346764087677,
            -0.1616893708705902,
            0.4771544337272644,
            0.502882719039917,
            0.4454941153526306,
            0.313443660736084,
            1.3923258781433105,
            -0.07238419353961945,
            -0.3452478051185608,
            0.07697200030088425,
            -0.19424647092819214,
            -0.40326178073883057,
            -0.5231634974479675,
        ]
    ]
}

test_train_request = {
    "dataset": {
        "credit score question": [
            "i want to learn more about credit score",
            "can you tell me more about credit score",
            "how do improve my credit score",
            "how is my credit score calculated",
        ],
        "fair lending question": [
            "i want to learn more about redlining",
            "what can you tell me about fair lending",
            "tell me about racial gap in homeownership",
        ],
        "choosing a lender": [
            "what kind of questions should I ask my lender",
            "how to find the best lender for me",
            "help me choose a lender",
        ],
        "show home of interests": [
            "show me different homes in different cities. thank you",
            "Are there any homes in the area within my budget?",
            "What homes are for sale according to my budget?",
            "I am looking for a beautiful low budget house. suggest me some. thank you",
            "can you show me some homes that are of interests to me?",
            "need some suggestions on homes to buy",
            "can you provide a few houses for me to look at?",
            "based on my history and preferences, can you recommend a few homes for me?",
            "can you suggest three homes for me to take a look",
            "Could you show me some homes that may be of interest to me?",
        ],
        "tell a joke": [
            "hey can you tell me a joke",
            "can you make me laugh?",
            "do you know of any jokes",
            "i want to laugh, tell me a joke please",
        ],
        "greeting": [
            "hello",
            "hi",
            "hey",
            "how's it going",
            "how are you",
            "whats up",
            "what's going on",
            "what's good",
            "how goes it",
        ],
        "need links": [
            "can you give me some links on that",
            "i want to learn more on that, can you give me some links",
            "interesting, can you give me some additional resources for me read up on",
            "hook me up with some links please",
            "alright send me some links to read up on",
        ],
        "ask about home price": [
            "I am looking to buy a house, how is the housing market these days?",
            "how do the current housing market look?",
            "how is the current housing market",
            "How are home prices looking in North Carolina?",
            "Can you tell me what the average price is on homes in the Washington D.C. area and what they are selling for currently?",
            "I want to live in the city center of Chicago. What is the general price for a home in that area?",
            "what is the median home price in Phoenix, Arizona?",
            "Can you tell me the prices of homes in the Brooklyn area of New York?",
            "What are the average house prices in Tampa Florida?",
            "How much does an average home cost in Houston, Texas?",
            "What is the housing market like in wyoming?",
            "Can you give me some idea of what the average home is selling for in the area we are looking?  Do you know what we could expect to spend?",
            "What are the prices of homes in this area ?",
            "What is the usual or average prices of homes here in rural Nebraska?",
            "What is the average home price in Cleveland Ohio?",
            "how much are homes going for in this area?",
            "How much will I need to have in order to buy a home in this area?",
            "what is the average price of a home in my area",
            "Can you give some information about home prices in Miami?",
            "can i get details of a purchasing home in the texas area",
            "Can you tell me the average home price in the downtown Chicago area?",
            "Hello, I'm interested in buying a home in Grand Blanc, MI.  Could you please tell me the starting prices of a 3 bedroom single story home?",
            "I am looking to buy a home in Phoenix and was wondering what the average prices are?",
            "What is the average price of a two bedroom condo in Downtown Calgary, Alberta?",
            "What are the median prices for homes in washington, DC?",
            "What is the Property Rates & Price Trends in Pondicherry?",
            "What are the average home prices in the Houston Texas area?",
            "What are the prices of homes in Orlando, Florida?",
            "what is the current price of homes in California state?",
            "What is the average price for a home in Chicago?",
            "What are the average home prices in Denver, Colorado?",
            "What is the average cost of a home in Pittsburgh?",
            "My area is in Lakewood, WA. I would like to buy a New Home in this Area.",
            "What is the median housing price of Columbus?",
            "What is the price of an apartment in california?",
            "What is the average cost on a home in the Fort Worth, Texas area?",
            "What's the cost of a home in the Summerlin area of Las Vegas, Nevada?",
            "What about price range in cities like california?",
            "what's the average range for a mid-size family home here? how much over are houses going?",
            "What is the median price of a two bedroom home in and around the Boston area in Massachusetts?",
            "Im considering purchasing a house in this area and Im wondering what the prices are in this area?",
        ],
        "purchase ready advice": [
            "Can you give me some tips on how to effectively save up for buying a home?",
            "What do you advise for me to do to make sure I am ready to buy?",
            "What can I do to be prepared for this purchase?",
            "How do I get myself ready to purchase a home?",
            "How can I save some money to buy a home?",
            "How much do I need to save for the down payment on my new home, if the purchase price is $200,000?",
            "I have to spend less from now on",
            "I would like to start the process of buying a home shorty. Can you tell me what I should be doing to prepare and be in a position to be ready to purchase?",
            "What would I need to do to make myself purchase ready?",
            "What do I need to do in order to make sure that I am prepared to buy a home?",
            "How do I know when I have saved enough to buy?",
            "I'm wanting to buy a house and I'm wanting to know how much I would need to have saved for a down payment?",
            "What can I do to make myself ready to buy a home?",
            "What advice do you have for me on what I specifically need to do to prepare to buy?",
            "What should I do to be ready to buy a home ?",
            "What are the top three things people do to financially prepare to buy a home?",
            "In regards to the house, how much money do I need to have available so we are purchase ready?",
            "How can I save enough money to buy a home?",
            "How much should I be expected to save in order to purchase a home?",
            "How much money should I save in order to buy a home?",
            "give me some suggestions on how to make myself purchase ready",
            "What are the steps of home buying process and what should I be prepared for?",
            "Is there a spreadsheet for saving and budgetting i can access?",
            "How can I start saving up to buy a house?",
            "How much money should I have saved in order to purchase a home ?",
        ],
        "loan approval probability": [
            "What are my chances of getting an approval for a loan ?",
            "What can I do to improve my chances of being approved for a loan?",
            "How much chance do I have to get an approval for a loan to buy a nice home?",
            "What is the possibility of getting a loan with my salary slip?",
            "So what are my chances of getting approved for this loan?",
            "Am I qualified for any loan approvals?",
            "How do my current finances and credit rating reflect on my ability to get a loan approval at the moment?",
            "Calculate my chances of getting home loan approval",
            "I'm wanting to purchase a house and I'm wanting to know if I would be able to get a loan?",
            "What is the likelihood that I will get approved for a home loan?",
            "I want to find out what my chances are of getting approved for a home loan.",
            "What are my chances of getting approved for a home loan?",
            "What are the chances of me getting a loan?",
            "What are my chances of actually getting the loan?",
            "What are my chances of getting approved for a loan?",
            "How likely will I get a loan from the bank to buy a home?",
            "What do you think my chances are of getting approved for a loan?",
            "How is the loan approval rate?",
            "What are the chances I will be approved for a loan?",
            "What type of credit do I have to have to qualify? ",
            "What are the eligibility and approval criterion for home loans?",
            "What qualification are there to get approved for a home loan?",
            "How likely is it that I will get approved for a mortgage loan?",
            "What are the qualifications of being approved for the best loan?",
            "Can you tell me how likely it will be for me to get approved for a home loan?",
            "So what are my chances of getting approved for a loan?",
        ],
        "agreement": [
            "yes let's do it",
            "I agree with you",
            "That's so true",
            "that's for sure",
            "for sure",
            "you are absolutely right",
            "absolutely",
            "that's exactly how i feel",
            "i suppose so",
            "i guess so",
            "you have a point there",
            "yes",
            "let's give it a try",
            "that sounds like a good idea",
            "can you hook me up",
            "please do",
            "you read my mind",
            "i was just going to say that",
            "good idea",
            "good call",
        ],
        "disagreement": [
            "i don't think so",
            "no",
            "nope",
            "nah",
            "no way",
            "i disagree",
            "that is not necessary",
            "not necessarily",
            "that's not true",
            "i am not sure about that",
            "let's hold off on that for now",
            "hold that thought",
            "we can come back to this later",
            "let's revisit this later",
            "bad idea",
            "bad call",
        ],
    },
    "from_scratch": False,
    "training_parameters": {"num_train_epochs": 2},
}
test_infer_request = {
    "contexts": ["Share my location with Hillary's sister"],
    "candidates": [
        "searchplace",
        "getplacedetails",
        "bookrestaurant",
        "gettrafficinformation",
        "compareplaces",
        "sharecurrentlocation",
        "requestride",
        "getdirections",
        "shareeta",
        "getweather",
    ],
    "context_type": "text",
    "candidate_type": "text",
}

train_config_default = {
    "max_contexts_length": 128,
    "max_candidate_length": 64,
    "train_batch_size": 8,
    "eval_batch_size": 2,
    "max_history": 4,
    "learning_rate": 1e-3,
    "weight_decay": 0.01,
    "warmup_steps": 100,
    "adam_epsilon": 1e-6,
    "max_grad_norm": 1,
    "num_train_epochs": 10,
    "gradient_accumulation_steps": 1,
    "fp16": False,
    "fp16_opt_level": "O1",
    "gpu": 0,
    "basepath": "logoutput",
    "seed": 12345,
    "device": "cuda",
}


model_config_default = {
    "shared": False,
    "model_name": "prajjwal1/bert-tiny",
    "model_save_path": "modeloutput",
    "loss_function": "mse",
    "loss_type": "dot",
}
